@@ -474,9 +474,8 @@ FeedHandlerInfo.prototype = {
 
   _shellSvc:
 //@line 541 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
-    Cc["@mozilla.org/browser/shell-service;1"].
-    getService(Ci.nsIShellService),
-//@line 546 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+    getShellService(),
+//@line 545 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
 
 
   //**************************************************************************//
@@ -599,14 +598,14 @@ FeedHandlerInfo.prototype = {
       return this.__defaultApplicationHandler;
 
     var defaultFeedReader = null;
-//@line 669 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 668 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     try {
       defaultFeedReader = this._shellSvc.defaultFeedReader;
     }
     catch(ex) {
-      // no default reader
+      // no default reader or _shellSvc is null
     }
-//@line 676 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 675 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
 
     if (defaultFeedReader) {
       let handlerApp = Cc["@mozilla.org/uriloader/local-handler-app;1"].
@@ -625,15 +624,15 @@ FeedHandlerInfo.prototype = {
   },
 
   get hasDefaultHandler() {
-//@line 695 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 694 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     try {
       if (this._shellSvc.defaultFeedReader)
         return true;
     }
     catch(ex) {
-      // no default reader
+      // no default reader or _shellSvc is null
     }
-//@line 703 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 702 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
 
     return false;
   },
@@ -917,6 +916,10 @@ var gApplicationsPane = {
       self._rebuildVisibleTypes();
       self._sortVisibleTypes();
       self._rebuildView();
+
+      // Notify observers that the UI is now ready
+      Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService).
+      notifyObservers(window, "app-handler-pane-loaded", null);
     }
     setTimeout(_delayedPaneLoad, 0, this);
   },
@@ -1287,7 +1290,7 @@ var gApplicationsPane = {
 //          just don't know how to do that via script...
 // XXXmano TBD: can probably add this to nsIShellService
    aExecutable.leafName != "firefox-bin";
-//@line 1364 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1367 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
   },
 
   /**
@@ -1408,7 +1411,7 @@ var gApplicationsPane = {
     }
 
     // Create a menu item for selecting a local application.
-//@line 1491 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1494 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     {
       let menuItem = document.createElement("menuitem");
       menuItem.setAttribute("oncommand", "gApplicationsPane.chooseApp(event)");
@@ -1650,7 +1653,7 @@ var gApplicationsPane = {
 
     var handlerApp;
 
-//@line 1762 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1765 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
     var fp = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
     var winTitle = this._prefsBundle.getString("fpTitleChooseApp");
     fp.init(window, winTitle, Ci.nsIFilePicker.modeOpen);
@@ -1669,7 +1672,7 @@ var gApplicationsPane = {
       let handlerInfo = this._handledTypes[this._list.selectedItem.type];
       handlerInfo.addPossibleApplicationHandler(handlerApp);
     }
-//@line 1781 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
+//@line 1784 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/preferences/applications.js"
 
     // Rebuild the actions menu whether the user picked an app or canceled.
     // If they picked an app, we want to add the app to the menu and select it.
